Software Heritage - Bazaar/Breezy loader
========================================

Loader for `Bazaar <http://bazaar.canonical.com/en/>`_ and `Breezy
<https://www.breezy-vcs.org/>`_ repositories. Breezy is a friendly fork of Bazaar that
supports the Bazaar file format and network protocol.
